function [B_r, B_z] = B_ellip(r_c,z,I_0,z_0,a)
% Performs B calculation according to Appendix B of Schill, Robert A., "General Relation 
% for the Vector Magnetic Field of a Circular Current Loop: A Closer Look," IEEE
% Transactions On Magnetics, Vol. 39, No. 2, March 2003. (r_c,z) is the observation
% point, meters in cylindrical coords; I_0 is the current; z_0 is the coil position 
% along the z-axis; a is the coil radius 
mu_0 = pi*4E-7;
[K,E] = ellipke(4*a*r_c/((r_c + a)^2 + (z - z_0)^2));
B_c = mu_0*I_0/(2*pi*sqrt((r_c +a)^2 + (z-z_0)^2));
B_r = B_c*((z-z_0)/r_c) * (-K+((r_c^2 + a^2 + (z-z_0)^2)/((r_c - a)^2 + (z-z_0)^2))*E);% B1
B_z = B_c*(K-((r_c^2 - a^2 + (z-z_0)^2)/((r_c - a)^2 + (z-z_0)^2))*E); % B2
